//
//  PriceCategory.m
//  Homepwner
//
//  Created by Daniel Dyba on 2/6/12.
//

#import "PriceCategory.h"
#import "PossessionStore.h"
#import "Possession.h"

@interface PriceCategory (Private)
+ (void)setUpPriceCategories;
+ (int)categoryCount;
+ (NSArray *)categoryNames;
@end

@implementation PriceCategory

static NSMutableArray *allCategories = nil;

+ (NSMutableArray *)allCategories
{
    if (allCategories == nil) {
        [self setUpPriceCategories];
    }
    
    return allCategories;
}

+ (void)setUpPriceCategories
{
    NSMutableArray *categories = [[NSMutableArray alloc] initWithCapacity:[self categoryCount]];
    
    // Categorize all possessions based on price
    for (int categoryID = 0; categoryID < [self categoryCount]; categoryID++) {

        NSMutableArray *possessionsInCategory = nil;
        
        for (Possession *p in [[PossessionStore defaultStore] allPossessions]) {

            if (possessionsInCategory == nil) {
                possessionsInCategory = [[NSMutableArray alloc] init];
            }
            
            // Add the possession to the category
            if ([p valueInDollars] < 50 && categoryID == 0) {
                [possessionsInCategory addObject:p];
            } else if ([p valueInDollars] >= 50 && categoryID == 1) {
                [possessionsInCategory addObject:p];
            }
        }
        
        [categories addObject:possessionsInCategory];
        
        if (possessionsInCategory) {
            [possessionsInCategory release];
        }
    }
    
    allCategories = categories;
}

+ (int)categoryCount
{
    BOOL hasPossessionUnder50 = false;
    BOOL hasPossessionEqualToOrAbove50 = false;
    int numberOfCategories = 1;
    
    for (Possession *p in [[PossessionStore defaultStore] allPossessions]) {
        if ([p valueInDollars] < 50) {
            hasPossessionUnder50 = true;
        } else if ([p valueInDollars] >= 50) {
            hasPossessionEqualToOrAbove50 = true;
        }
        
        if (hasPossessionUnder50 && hasPossessionEqualToOrAbove50) { break; }
    }
    
    if (hasPossessionUnder50 && hasPossessionUnder50) {
        numberOfCategories = 2;
    }
    
    return numberOfCategories;
}

+ (NSArray *)categoryNames
{
    NSArray *categoryNames = [NSArray arrayWithObjects:@"Under $50", @"$50 and Above", nil];
    
    return categoryNames;
}

@end
