//
//  ItemsViewController.m
//  Homepwner
//
//  Created by Daniel Dyba on 2/3/12.
//

#import "ItemsViewController.h"
#import "PossessionStore.h"
#import "Possession.h"
#import "PriceCategory.h"

@implementation ItemsViewController

@synthesize priceCategories;

- (id)init
{
    // Call the superclass's designated initializer
    self = [super initWithStyle:UITableViewStyleGrouped];
    
    if (self) {
        // [PriceCategory allCategories];
        
        // Create a new bar button item that will send
        // addNewPossession: to ItemsViewController
        UIBarButtonItem *bbi = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd
                                                                             target:self
                                                                             action:@selector(addNewPossession:)];
        
        // Set this bar button item as the right item in the navigationItem
        [[self navigationItem] setRightBarButtonItem:bbi];
        
        // The navigationItem retains its buttons, so bbi can be released
        [bbi release];
        
        // Set the title of the navigation item
        [[self navigationItem] setTitle:@"Homepwner"];
        
        // Set an edit button on the left hand side of the navigation bar 
        [[self navigationItem] setLeftBarButtonItem:[self editButtonItem]];
    }

    return self;
}

- (id)initWithStyle:(UITableViewStyle)style
{
    return [self init];
}

- (void)addNewPossession:(id)sender
{
    [[PossessionStore defaultStore] createPossession];
    
    // tableView returns the controller's view
    [[self tableView] reloadData];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [[self tableView] reloadData];
}

/* UITableViewDataSource Protocol Methods */

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Check for a reusable cell first, use that if it exists
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"UITableViewCell"];
    
    if (!cell) {
        // If there is no reusable cell of this type, create a new one...
        // Create an instance of UITableViewCell, with default appearance
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault
                                       reuseIdentifier:@"UITableViewCell"] autorelease];
    }
    
    // NSMutableArray *possessions = [[PriceCategory allCategories] objectAtIndex:[indexPath section]];
    // Possession *p [possessions objectAtIndex:[indexPath row]];

    Possession *p = [[[PossessionStore defaultStore] allPossessions] objectAtIndex:[indexPath row]];

    [[cell textLabel] setText:[p description]];
    
    return cell;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{   
    // return [[[PriceCategory allCategories] objectAtIndex:section] count];
    return [[[PossessionStore defaultStore] allPossessions] count];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    // return [[PriceCategory categoryNames] count];
    return 1;
}
/*
- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section
{
    return [[PriceCategory categoryNames] objectAtIndex:section];
}
*/

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    // If the table view is asking to commit a delete command...
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        PossessionStore *ps = [PossessionStore defaultStore];
        NSArray *possessions = [ps allPossessions];
        Possession *p = [possessions objectAtIndex:[indexPath row]];
        [ps removePossession:p];
        
        // We also remove that row from the table view with an animation
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:YES];
    }
}

- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)sourceIndexPath toIndexPath:(NSIndexPath *)destinationIndexPath
{
    [[PossessionStore defaultStore] movePossessionAtIndex:[sourceIndexPath row] toIndex:[destinationIndexPath row]];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    ItemDetailViewController *detailViewController = [[[ItemDetailViewController alloc] init] autorelease];
    
    NSArray *possessions = [[PossessionStore defaultStore] allPossessions];
    
    // Give detail view controller a pointer to the possession object in row
    [detailViewController setPossession:[possessions objectAtIndex:[indexPath row]]];
    
    // Push it onto the top of the navigation controller's stack
    [[self navigationController] pushViewController:detailViewController animated:YES];
}

@end